Prepares the LUH3 historic flood data for usage in MAgPIE, by calculating the share of c3ann with c3ann area in Mha to obtain flood area in Mha.
Usage
calcLUH3flood(cellular = FALSE, yrs = seq(1965, 2020, 5))Prepares the LUH3 historic flood data for usage in MAgPIE, by calculating the share of c3ann with c3ann area in Mha to obtain flood area in Mha.
calcLUH3flood(cellular = FALSE, yrs = seq(1965, 2020, 5))